@@ -15,15 +15,23 @@
  */
 package net.morilib.awk.builtin;
 
+import net.morilib.awk.misc.AwkComplexMath;
+import net.morilib.awk.value.AwkValue;
+
+/**
+ * 組み込み関数sinの記述です。
+ *
+ *
+ * @author MORIGUCHI, Yuichiro 2013/04/13
+ */
 public class AwkSin extends AwkMathFunction {
 
 	protected AwkSin() {
 		super("sin");
 	}
 
-	@Override
-	protected double f(double x) {
-		return Math.sin(x);
+	protected AwkValue f(AwkValue x) {
+		return AwkComplexMath.sin(x);
 	}
 
 }
