@@ -38,6 +38,10 @@ public class AwkString extends AwkValue {
 	private static final Pattern PIT = Pattern.compile("[-+]?[0-9]+");
 	private static final Pattern PDC = Pattern.compile(
 			"[-+]?([0-9]*\\.[0-9]+)([eE][-+]?[0-9]+)?");
+	private static final Pattern PFI = Pattern.compile(
+			"([-+]?([0-9]+(\\.[0-9]+)?|\\.[0-9]+)([eE][-+]?[0-9]+)?)" +
+			"([-+]([0-9]+(\\.[0-9]+)?|\\.[0-9]+)([eE][-+]?[0-9]+)?)" +
+			"[ij]");
 
 	//
 	private String value;
@@ -87,10 +91,45 @@ public class AwkString extends AwkValue {
 		}
 	}
 
+	public double toImaginary() {
+		Matcher m;
+
+		if((m = PFI.matcher(value)).lookingAt()) {
+			return Double.parseDouble(
+					m.group(5).replaceFirst("^\\+", ""));
+		} else {
+			return 0.0;
+		}
+	}
+
 	public boolean toBoolean(AwkNamespace ns) {
 		return !value.equals("");
 	}
 
+	public AwkValue toNumber() {
+		Matcher m;
+
+		if((m = PFI.matcher(value)).lookingAt()) {
+			return AwkComplex.valueOf(
+					Double.parseDouble(
+							m.group(1).replaceFirst("^\\+", "")),
+					Double.parseDouble(
+							m.group(5).replaceFirst("^\\+", "")));
+		} else if((m = PFL.matcher(value)).lookingAt()) {
+			if(PIT.matcher(m.group()).matches()) {
+				return AwkInteger.valueOf(
+						new BigInteger(
+								m.group().replaceFirst("^\\+", "")));
+			} else {
+				return AwkFloat.valueOf(
+						Double.parseDouble(
+								m.group().replaceFirst("^\\+", "")));
+			}
+		} else {
+			return AwkInteger.ZERO;
+		}
+	}
+
 	public Pattern toRegex() {
 		return Pattern.compile(value);
 	}
@@ -188,8 +227,10 @@ public class AwkString extends AwkValue {
 	public int compareTo(AwkValue o, AwkNamespace ns) {
 		if(o instanceof AwkUndefined) {
 			return 1;
+		} else if(ns.isIgnoreCase()) {
+			return toString(ns).compareToIgnoreCase(o.toString(ns));
 		} else {
-			return value.compareTo(o.toString(ns));
+			return toString(ns).compareTo(o.toString(ns));
 		}
 	}
 
